# cgt

Combinatorial Game Theory framework in Rust and Python.

## CLI utility tool

Some of the library features are exposed through CLI utility tool. See [CLI README](./cgt_cli/README.md) for installation and usage instructions.

## Rust

[Documentation](https://docs.rs/cgt/latest/cgt/)

## Python

Not published yet

Python interface is inteded as a thin wrapper for interactive exploration using notebook software like [Jupyter](https://jupyter.org/) rather than exhaustive searches of large search spaces.

## Credits

- Library is heavily inspired by https://github.com/aaron-siegel/cgsuite
- Library in Haskell that provides basic functions to work with combinatorial games https://github.com/kamekura/haskell-cgt

## License

Copyright (C) 2023-2024 Tomasz Maciosowski (t4ccer)

This program is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.
